Crate uu_ls

Crate uu_ls 

Re-exports

pub use output::EntryInfo;
pub use output::LsOutput;
pub use output::StreamMode;
pub use output::StreamingOutput;

Modules

options
output
Output traits and types for programmatic access to ls functionality.

Structs

Config
PathData
Represents a Path along with it’s associated data. Any data that will be reused several times makes sense to be added to this structure. Caching data here helps eliminate redundant syscalls to fetch same information. Internal representation of file/directory entry data.
TextOutput
Text output implementation that formats entries for terminal display.

Enums

Format

Functions

list
Lists files and directories with text output to stdout.
list_with_output
Lists files and directories, sending structured output to a custom sink.
uu_app
uumain