TextOutput

Struct TextOutput 

pub struct TextOutput<'a> { /* private fields */ }
Text output implementation that formats entries for terminal display.

This is the default output sink used by list for standard ls behavior. It handles all text formatting including colors, columns, long format, etc.

Implementations

Source

impl<'a> TextOutput<'a>

pub fn new(config: &'a Config) -> Self