Represents a Path along with it’s associated data.
Any data that will be reused several times makes sense to be added to this structure.
Caching data here helps eliminate redundant syscalls to fetch same information.
Internal representation of file/directory entry data.