pub struct TextOutput<'a> { /* private fields */ }Expand description
Text output implementation that formats entries for terminal display.
This is the default output sink used by list for standard ls behavior.
It handles all text formatting including colors, columns, long format, etc.
Implementations